# noci

## Concept
noci is a utility package for automation tasks

## Packaging
1. install twine

    python3 -m pip install --upgrade twine

2. upload

    python3 -m twine upload --repository noci dist/*
